@@ -3,9 +3,11 @@ from __future__ import annotations
 from pathlib import Path
 from typing import List, NamedTuple, Optional, Tuple
 
+import mecab_ko_dic
+
 import _mecab
 
-_mecabrc_path = Path(__file__).parent / "mecabrc"
+mecabrc_path = Path(__file__).absolute().parent / "mecabrc"
 
 
 def _create_lattice(sentence: str) -> _mecab.Lattice:
@@ -18,13 +20,13 @@ def _create_lattice(sentence: str) -> _mecab.Lattice:
 
 class Feature(NamedTuple):
     pos: str
-    semantic: Optional[str]
-    has_jongseong: Optional[bool]
-    reading: Optional[str]
-    type: Optional[str]
-    start_pos: Optional[str]
-    end_pos: Optional[str]
-    exprssion: Optional[str]
+    semantic: Optional[str] = None
+    has_jongseong: Optional[bool] = None
+    reading: Optional[str] = None
+    type: Optional[str] = None
+    start_pos: Optional[str] = None
+    end_pos: Optional[str] = None
+    exprssion: Optional[str] = None
 
     @classmethod
     def _from_node(cls, node: _mecab.Node) -> Feature:
@@ -57,22 +59,14 @@ class MeCabError(Exception):
 class MeCab:  # APIs are inspired by KoNLPy
     def __init__(self, dictionary_directory: Optional[str] = None):
         if dictionary_directory is None:
-            try:
-                import mecab_ko_dic
-
-                dictionary_directory = mecab_ko_dic.DICDIR
-            except ImportError:
-                raise MeCabError(
-                    "`mecab_ko_dic` not found. Please run `pip install mecab_ko_dic`"
-                )
+            dictionary_directory = mecab_ko_dic.DICDIR
 
         arguments = [
             "--rcfile",
-            str(_mecabrc_path),
+            str(mecabrc_path),
             "--dicdir",
             dictionary_directory,
         ]
-
         self.tagger = _mecab.Tagger(arguments)
 
     def parse(self, sentence: str) -> List[Tuple[str, Feature]]:
